/*
 * (C) Copyright 2023
 * Stefano Babic <stefano.babic@swupdate.org>
 *
 * SPDX-License-Identifier:     GPL-2.0-only
 */

#pragma once

#include "swupdate_settings.h"
void get_sw_versions(swupdate_cfg_handle *handle, struct swupdate_cfg *sw);

